==> mingw-w64-clang-aarch64-paraview-5.12.1-1-any.pkg.tar.zst: clangarm64/lib/cmake/paraview/DigitalRockPhysics-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonExecutionModel")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::ParallelCore")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_library_name" "vtkDigitalRocksFilters")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPMaterialClusterAnalysisFilter.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPMaterialClusterExplodeFilter.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkDigitalRocksFiltersModule.h")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/bin/paraview/plugins/DigitalRockPhysics/vtk/hierarchy/DigitalRockPhysics/vtkDigitalRocksFilters-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> mingw-w64-clang-aarch64-paraview-6.0.1-2-any.pkg.tar.zst: clangarm64/lib/cmake/paraview/DigitalRockPhysics-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonExecutionModel")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::ParallelCore")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_library_name" "vtkDigitalRocksFilters")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPMaterialClusterAnalysisFilter.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkPMaterialClusterExplodeFilter.h")
set_property(TARGET "DigitalRockPhysics::DigitalRocksFilters" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/bin/paraview/plugins/DigitalRockPhysics/vtk/hierarchy/DigitalRockPhysics/vtkDigitalRocksFilters-hierarchy.txt")
unset(_vtk_module_import_prefix)
